Basics
This check is disabled by default.
Learn how to enable it via .credo.exs.
This check has a base priority of high and works with any version of Elixir.
Explanation
Optional dependencies must be reached through Mailglass.OptionalDeps.*
gateway modules, never referenced directly from application code.
Check-Specific Parameters
Use the following parameters to configure this check:
:gated_modules
Map of optional dependency root modules to their required gateway module.
This parameter defaults to %{Oban => Mailglass.OptionalDeps.Oban, Mjml => Mailglass.OptionalDeps.Mjml, Sigra => Mailglass.OptionalDeps.Sigra, OpenTelemetry => Mailglass.OptionalDeps.OpenTelemetry, GenSmtp => Mailglass.OptionalDeps.GenSmtp}.
:included_path_prefixes
Only files in these path prefixes are linted.
This parameter defaults to ["lib/mailglass/"].
General Parameters
Like with all checks, general params can be applied.
Parameters can be configured via the .credo.exs config file.