Basics
This check is disabled by default.
Learn how to enable it via .credo.exs.
This check has a base priority of high and works with any version of Elixir.
Explanation
Library processes must not register as name: __MODULE__ by default.
Check-Specific Parameters
Use the following parameters to configure this check:
:watched_modules
Modules whose start_link calls are inspected.
This parameter defaults to [GenServer, Agent, Registry].
:included_path_prefixes
Only files in these path prefixes are linted.
This parameter defaults to ["lib/mailglass/"].
General Parameters
Like with all checks, general params can be applied.
Parameters can be configured via the .credo.exs config file.