Mailglass.Credo.NoOtherAppEnvReads (Mailglass v1.0.0)

Copy Markdown View Source

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of high and works with any version of Elixir.

Explanation

Mailglass library code must not read other applications' env via Application.get_env* / fetch_env*.

Check-Specific Parameters

Use the following parameters to configure this check:

:allowed_apps

Application atoms allowed as the first argument.

This parameter defaults to [:mailglass].

:included_path_prefixes

Only files in these path prefixes are linted.

This parameter defaults to ["lib/mailglass/"].

:watched_functions

Application env reader functions this check inspects.

This parameter defaults to [:get_env, :fetch_env, :fetch_env!].

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.