Mailglass.Credo.NoOversizedUseInjection (Mailglass v1.0.0)

Copy Markdown View Source

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of high and works with any version of Elixir.

Explanation

defmacro __using__/1 in Mailglass modules must keep injected code small. This check counts AST nodes in the returned quote body rather than macro-expanding the injection.

Check-Specific Parameters

Use the following parameters to configure this check:

:max_lines

Maximum count of tracked AST forms allowed in __using__/1.

This parameter defaults to 20.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.