Mailglass.Credo.NoPiiInTelemetryMeta (Mailglass v1.0.0)

Copy Markdown View Source

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of high and works with any version of Elixir.

Explanation

Telemetry metadata in mailglass must not include PII-shaped keys.

This check only analyzes literal metadata maps passed directly to :telemetry.execute/3 and :telemetry.span/3.

Check-Specific Parameters

Use the following parameters to configure this check:

:blocked_keys

Literal metadata keys that are considered PII.

This parameter defaults to [:to, :from, :cc, :bcc, :body, :html_body, :text_body, :subject, :headers, :recipient, :email].

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.