Mailglass.Credo.NoTrackingOnAuthStream (Mailglass v1.0.0)

Copy Markdown View Source

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of high and works with any version of Elixir.

Explanation

Auth-context mailable functions must not enable open/click tracking.

Check-Specific Parameters

Use the following parameters to configure this check:

:auth_name_heuristics

Function-name fragments treated as auth-context mailables.

This parameter defaults to ["magic_link", "password_reset", "verify_email", "confirm_account", "reset_token", "verification_token", "confirm_email", "two_factor", "2fa"].

:mailable_module

Module used to identify mailable modules (use Mailglass.Mailable).

This parameter defaults to Mailglass.Mailable.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.