Mailglass.Credo.RequireAtomicUnsubscribeHeaders (Mailglass v1.0.0)

Copy Markdown View Source

Basics

This check is disabled by default.

Learn how to enable it via .credo.exs.

This check has a base priority of high and works with any version of Elixir.

Explanation

RFC 8058 unsubscribe headers must be written atomically through Mailglass.Compliance.inject_unsubscribe_headers/2.

Check-Specific Parameters

There are no specific parameters for this check.

General Parameters

Like with all checks, general params can be applied.

Parameters can be configured via the .credo.exs config file.