Mailglass.PublishError exception (Mailglass v1.0.0)

Copy Markdown View Source

Raised when installer golden drift is detected during the mix mailglass.publish.check task.

Types

  • :publish_blocked_golden_drift — the generated installer snippets do not match the expected goldens.

Summary

Functions

Returns the closed set of valid :type atoms.

Types

t()

@type t() :: %Mailglass.PublishError{
  __exception__: true,
  cause: Exception.t() | nil,
  context: %{required(atom()) => term()},
  message: String.t(),
  type: :publish_blocked_golden_drift
}

Functions

__types__()

(since 0.2.0)

Returns the closed set of valid :type atoms.

new(type, opts \\ [])

(since 0.2.0)
@spec new(
  atom(),
  keyword()
) :: t()

Build a Mailglass.PublishError struct.