Basics
This check is disabled by default.
Learn how to enable it via .credo.exs.
This check has a base priority of high and works with any version of Elixir.
Explanation
Application.compile_env* calls are only allowed inside Mailglass.Config.
Check-Specific Parameters
Use the following parameters to configure this check:
:allowed_modules
Modules allowed to call Application.compile_env*.
This parameter defaults to [Mailglass.Config].
:included_path_prefixes
Only files in these path prefixes are linted.
This parameter defaults to ["lib/mailglass/"].
:blocked_functions
Application functions treated as compile-time env reads.
This parameter defaults to [:compile_env, :compile_env!].
General Parameters
Like with all checks, general params can be applied.
Parameters can be configured via the .credo.exs config file.