Basics
This check is disabled by default.
Learn how to enable it via .credo.exs.
This check has a base priority of high and works with any version of Elixir.
Explanation
Phoenix.PubSub topics used by mailglass must use the mailglass:
namespace prefix.
Check-Specific Parameters
Use the following parameters to configure this check:
:required_prefix
Required topic prefix for literal PubSub topic strings.
This parameter defaults to "mailglass:".
General Parameters
Like with all checks, general params can be applied.
Parameters can be configured via the .credo.exs config file.