Basics
This check is disabled by default.
Learn how to enable it via .credo.exs.
This check has a base priority of high and works with any version of Elixir.
Explanation
Mailable tracking requires an explicit :bulk or :operational stream.
Check-Specific Parameters
Use the following parameters to configure this check:
:mailable_module
Module used to identify mailable modules (use Mailglass.Mailable).
This parameter defaults to Mailglass.Mailable.
General Parameters
Like with all checks, general params can be applied.
Parameters can be configured via the .credo.exs config file.