Basics
This check is disabled by default.
Learn how to enable it via .credo.exs.
This check has a base priority of high and works with any version of Elixir.
Explanation
Telemetry event names must follow mailglass's 4-level convention and
start with :mailglass.
Check-Specific Parameters
Use the following parameters to configure this check:
:required_root
First segment required in telemetry event lists.
This parameter defaults to :mailglass.
:min_segments
Minimum number of literal atom segments required.
This parameter defaults to 4.
General Parameters
Like with all checks, general params can be applied.
Parameters can be configured via the .credo.exs config file.